@@ -1,9 +1,6 @@
 from contextlib import contextmanager
 import os
 from os import path
-from webassets import six
-from webassets.six.moves import map
-from webassets.six.moves import zip
 
 from .filter import get_filter
 from .merge import (FileHunk, UrlHunk, FilterTool, merge, merge_filters,
@@ -12,7 +9,7 @@ from .updater import SKIP_CACHE
 from .exceptions import BundleError, BuildError
 from .utils import cmp_debug_levels, hash_func
 from .env import ConfigurationContext, DictConfigStorage, BaseEnvironment
-from .utils import is_url
+from .utils import is_url, calculate_sri_on_file
 
 
 __all__ = ('Bundle', 'get_all_bundle_files',)
@@ -115,7 +112,9 @@ class Bundle(object):
         self.filters = options.pop('filters', None)
         self.depends = options.pop('depends', [])
         self.version = options.pop('version', [])
+        self.remove_duplicates = options.pop('remove_duplicates', True)
         self.extra = options.pop('extra', {})
+        self.merge = options.pop('merge', True)
 
         self._config = BundleConfig(self)
         self._config.update(options.pop('config', {}))
@@ -145,7 +144,7 @@ class Bundle(object):
     def _get_debug(self):
         return self.config.get('debug', None)
     def _set_debug(self, value):
-        self.config['debug'] = True
+        self.config['debug'] = value
     debug = property(_get_debug, _set_debug)
 
     def _get_filters(self):
@@ -159,12 +158,9 @@ class Bundle(object):
             self._filters = ()
             return
 
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             # 333: Simplify w/o condition?
-            if six.PY3:
-                filters = map(str.strip, value.split(','))
-            else:
-                filters = map(unicode.strip, unicode(value).split(','))
+            filters = map(str.strip, value.split(','))
         elif isinstance(value, (list, tuple)):
             filters = value
         else:
@@ -250,13 +246,31 @@ class Bundle(object):
 
                 resolved.extend(map(lambda r: (item, r), result))
 
+            # Exclude duplicate files from the bundle.
+            # This will only keep the first occurrence of a file in the bundle.
+            if self.remove_duplicates:
+                resolved = self._filter_duplicates(resolved)
+
             self._resolved_contents = resolved
+
         return self._resolved_contents
 
+    @staticmethod
+    def _filter_duplicates(resolved):
+        # Keep track of the resolved filenames that have been seen, and only
+        # add it the first time it is encountered.
+        seen_files = set()
+        result = []
+        for item, r in resolved:
+            if r not in seen_files:
+                seen_files.add(r)
+                result.append((item, r))
+        return result
+
     def _get_depends(self):
         return self._depends
     def _set_depends(self, value):
-        self._depends = [value] if isinstance(value, six.string_types) else value
+        self._depends = [value] if isinstance(value, str) else value
         self._resolved_depends = None
     depends = property(_get_depends, _set_depends, doc=
     """Allows you to define an additional set of files (glob syntax
@@ -372,7 +386,7 @@ class Bundle(object):
     env = property(_get_env, _set_env)
 
     def _merge_and_apply(self, ctx, output, force, parent_debug=None,
-                         parent_filters=[], extra_filters=[],
+                         parent_filters=None, extra_filters=None,
                          disable_cache=None):
         """Internal recursive build method.
 
@@ -396,6 +410,8 @@ class Bundle(object):
         (for now).
         """
 
+        parent_filters = parent_filters or []
+        extra_filters = extra_filters or []
         # Determine the debug level to use. It determines if and which filters
         # should be applied.
         #
@@ -551,7 +567,7 @@ class Bundle(object):
         # being possibly configured with cache reads off).
         return filtertool.apply(final, selected_filters, 'output')
 
-    def _build(self, ctx, extra_filters=[], force=None, output=None,
+    def _build(self, ctx, extra_filters=None, force=None, output=None,
                disable_cache=None):
         """Internal bundle build function.
 
@@ -571,6 +587,7 @@ class Bundle(object):
         should lock, so that multiple requests don't all start to build. When
         called from the command line, there is no need to lock.
         """
+        extra_filters = extra_filters or []
 
         if not self.output:
             raise BuildError('No output target found for %s' % self)
@@ -714,6 +731,8 @@ class Bundle(object):
         """Return a list of urls for this bundle, and all subbundles,
         and, when it becomes necessary, start a build process.
         """
+        # Check if we should calculate SRI
+        calculate_sri = kwargs.pop('calculate_sri', False)
 
         # Look at the debug value to see if this bundle should return the
         # source urls (in debug mode), or a single url of the bundle in built
@@ -741,7 +760,11 @@ class Bundle(object):
             if ctx.auto_build:
                 self._build(ctx, extra_filters=extra_filters, force=False,
                             *args, **kwargs)
-            return [self._make_output_url(ctx)]
+            if calculate_sri:
+                return [{'uri': self._make_output_url(ctx),
+                         'sri': calculate_sri_on_file(ctx.resolver.resolve_output_to_path(ctx, self.output, self))}]
+            else:
+                return [self._make_output_url(ctx)]
         else:
             # We either have no files (nothing to build), or we are
             # in debug mode: Instead of building the bundle, we
@@ -752,20 +775,34 @@ class Bundle(object):
                     urls.extend(org._urls(
                         wrap(ctx, cnt),
                         merge_filters(extra_filters, self.filters),
-                        *args, **kwargs))
+                        *args,
+                        calculate_sri=calculate_sri,
+                        **kwargs))
                 elif is_url(cnt):
-                    urls.append(cnt)
+                    # Can't calculate SRI for non file
+                    if calculate_sri:
+                        urls.append({'uri': cnt, 'sri': None})
+                    else:
+                        urls.append(cnt)
                 else:
+                    sri = None
                     try:
                         url = ctx.resolver.resolve_source_to_url(ctx, cnt, org)
+                        if calculate_sri:
+                            sri = calculate_sri_on_file(ctx.resolver.resolve_output_to_path(ctx, cnt, org))
                     except ValueError:
                         # If we cannot generate a url to a path outside the
                         # media directory. So if that happens, we copy the
                         # file into the media directory.
                         external = pull_external(ctx, cnt)
                         url = ctx.resolver.resolve_source_to_url(ctx, external, org)
+                        if calculate_sri:
+                            sri = calculate_sri_on_file(ctx.resolver.resolve_output_to_path(ctx, external, org))
 
-                    urls.append(url)
+                    if calculate_sri:
+                        urls.append({'uri': url, 'sri': sri})
+                    else:
+                        urls.append(url)
             return urls
 
     def urls(self, *args, **kwargs):
@@ -777,6 +814,12 @@ class Bundle(object):
 
         Insofar necessary, this will automatically create or update the files
         behind these urls.
+
+        :param calculate_sri: Set to true to calculate a sub-resource integrity
+        string for the URLs. This changes the returned format.
+
+        :return: List of URIs if calculate_sri is False. If calculate_sri is
+                 true: list of {'uri': '<uri>', 'sri': '<sri-hash>'}.
         """
         ctx = wrap(self.env, self)
         urls = []
