@@ -7,6 +7,7 @@ This can be used as an alternative to an imperative setup.
 import os, sys
 from os import path
 import glob, fnmatch
+import inspect
 import types
 try:
     import yaml
@@ -15,6 +16,8 @@ except ImportError:
 
 from webassets import Environment
 from webassets.bundle import Bundle
+from webassets.exceptions import EnvironmentError
+from webassets.filter import register_filter
 from webassets.importlib import import_module
 
 
@@ -48,7 +51,7 @@ class YAMLLoader(object):
         Each item yielded will be either a string representing a file path
         or a bundle."""
         contents = data.get('contents', [])
-        if isinstance(contents, basestring):
+        if isinstance(contents, str):
             contents = contents,
         for content in contents:
             if isinstance(content, dict):
@@ -62,13 +65,14 @@ class YAMLLoader(object):
             output=data.get('output', None),
             debug=data.get('debug', None),
             extra=data.get('extra', {}),
+            config=data.get('config', {}),
             depends=data.get('depends', None))
         return Bundle(*list(self._yield_bundle_contents(data)), **kwargs)
 
-    def _get_bundles(self, obj):
+    def _get_bundles(self, obj, known_bundles=None):
         """Return a dict that keys bundle names to bundles."""
         bundles = {}
-        for key, data in obj.iteritems():
+        for key, data in obj.items():
             if data is None:
                 data = {}
             bundles[key] = self._get_bundle(data)
@@ -81,6 +85,8 @@ class YAMLLoader(object):
             for i, item in enumerate(bundle.contents):
                 if item in bundles:
                     contents[i] = bundles[item]
+                elif known_bundles and item in known_bundles:
+                    contents[i] = known_bundles[item]
             # cast back to a tuple
             contents = tuple(contents)
             if contents != bundle.contents:
@@ -92,13 +98,19 @@ class YAMLLoader(object):
 
         The filename can be False if it is unknown.
         """
-        if isinstance(self.file_or_filename, basestring):
+        if isinstance(self.file_or_filename, str):
             return open(self.file_or_filename), self.file_or_filename
 
         file = self.file_or_filename
         return file, getattr(file, 'name', False)
 
-    def load_bundles(self):
+    @classmethod
+    def _get_import_resolver(cls):
+        """ method that can be overridden in tests """
+        from zope.dottedname.resolve import resolve as resolve_dotted
+        return resolve_dotted
+
+    def load_bundles(self, environment=None):
         """Load a list of :class:`Bundle` instances defined in the YAML file.
 
         Expects the following format:
@@ -125,6 +137,10 @@ class YAMLLoader(object):
             jquery-ui:
                 contents: jqueryui/*.js
 
+        If an ``environment`` argument is given, it's bundles
+        may be referenced as well. Note that you may pass any
+        compatibly dict-like object.
+
         Finally, you may also use nesting:
 
         .. code-block:: yaml
@@ -141,8 +157,8 @@ class YAMLLoader(object):
         # as absolute paths" option?
         f, _ = self._open()
         try:
-            obj = self.yaml.load(f) or {}
-            return self._get_bundles(obj)
+            obj = self.yaml.safe_load(f) or {}
+            return self._get_bundles(obj, environment)
         finally:
             f.close()
 
@@ -157,6 +173,8 @@ class YAMLLoader(object):
             url: /media
             debug: True
             updater: timestamp
+            filters:
+                - my_custom_package.my_filter
             config:
                 compass_bin: /opt/compass
                 another_custom_config_value: foo
@@ -178,13 +196,14 @@ class YAMLLoader(object):
         """
         f, filename = self._open()
         try:
-            obj = self.yaml.load(f) or {}
+            obj = self.yaml.safe_load(f) or {}
 
             env = Environment()
 
             # Load environment settings
             for setting in ('debug', 'cache', 'versions', 'url_expire',
-                            'auto_build', 'url', 'directory',
+                            'auto_build', 'url', 'directory', 'manifest', 'load_path',
+                            'cache_file_mode',
                             # TODO: The deprecated values; remove at some point
                             'expire', 'updater'):
                 if setting in obj:
@@ -197,13 +216,33 @@ class YAMLLoader(object):
                     path.join(path.dirname(filename),
                               env.config['directory']))
 
+            # Treat the 'filters' option special, it should resolve the
+            # entries as classes and register them to the environment
+            if 'filters' in obj:
+                try:
+                    resolve_dotted = self._get_import_resolver()
+                except ImportError:
+                    raise EnvironmentError(
+                        "In order to use custom filters in the YAMLLoader "
+                        "you must install the zope.dottedname package")
+                for filter_class in obj['filters']:
+                    try:
+                        cls = resolve_dotted(filter_class)
+                    except ImportError:
+                        raise LoaderError("Unable to resolve class %s" % filter_class)
+                    if inspect.isclass(cls):
+                        register_filter(cls)
+                    else:
+                        raise LoaderError("Custom filters must be classes "
+                            "not modules or functions")
+
             # Load custom config options
             if 'config' in obj:
                 env.config.update(obj['config'])
 
             # Load bundles
             bundles = self._get_bundles(obj.get('bundles', {}))
-            for name, bundle in bundles.iteritems():
+            for name, bundle in bundles.items():
                 env.register(name, bundle)
 
             return env
@@ -216,6 +255,8 @@ class PythonLoader(object):
     retrieve the bundles defined there.
     """
 
+    environment = "environment"
+
     def __init__(self, module_name):
         if isinstance(module_name, types.ModuleType):
             self.module = module_name
@@ -223,8 +264,11 @@ class PythonLoader(object):
             sys.path.insert(0, '')  # Ensure the current directory is on the path
             try:
                 try:
+                    if ":" in module_name:
+                        module_name, env = module_name.split(":")
+                        self.environment = env
                     self.module = import_module(module_name)
-                except ImportError, e:
+                except ImportError as e:
                     raise LoaderError(e)
             finally:
                 sys.path.pop(0)
@@ -244,11 +288,13 @@ class PythonLoader(object):
     def load_environment(self):
         """Load an ``Environment`` defined in the Python module.
 
-        Expects a global name ``environment`` to be defined.
+        Expects as default a global name ``environment`` to be defined,
+        or overridden by passing a string ``module:environment`` to the
+        constructor.
         """
         try:
-            return getattr(self.module, 'environment')
-        except AttributeError, e:
+            return getattr(self.module, self.environment)
+        except AttributeError as e:
             raise LoaderError(e)
 
 
@@ -278,7 +324,7 @@ class GlobLoader(object):
     def with_file(self, filename, then_run):
         """Call ``then_run`` with the file contents.
         """
-        file = open(filename, 'r')
+        file = open(filename, 'rb')
         try:
             contents = file.read()
             try:
