@@ -1,9 +1,7 @@
-from __future__ import with_statement
-
 import os
-from nose.tools import assert_raises
 
-from webassets import six
+import pytest
+
 from webassets import Environment
 from webassets.env import RegisterError
 from webassets import Bundle
@@ -12,7 +10,7 @@ from webassets import Bundle
 class TestEnvApi(object):
     """General Environment functionality."""
 
-    def setup(self):
+    def setup_method(self):
         self.m = Environment(None, None)
 
     def test_register_single_bundle(self):
@@ -92,14 +90,14 @@ class TestEnvApi(object):
         env = Environment('tests')
 
         # No `output`
-        assert_raises(
+        pytest.raises(
             RegisterError, env.register,
             'base1', 'helpers.py', merge=False
         )
 
         # Nested bundle
         b = Bundle()
-        assert_raises(
+        pytest.raises(
             RegisterError, env.register,
             'base2', 'helpers.py', b, merge=False, output='a'
         )
@@ -107,8 +105,8 @@ class TestEnvApi(object):
     def test_register_invalid_call(self):
         """Test calling self.m.register with an invalid syntax.
         """
-        assert_raises(TypeError, self.m.register)
-        assert_raises(TypeError, self.m.register, 'one-argument-only')
+        pytest.raises(TypeError, self.m.register)
+        pytest.raises(TypeError, self.m.register, 'one-argument-only')
 
     def test_register_duplicate(self):
         """Test name clashes.
@@ -125,8 +123,8 @@ class TestEnvApi(object):
         assert len(self.m) == 1
 
         # Otherwise, an error is raised.
-        assert_raises(RegisterError, self.m.register, 'foo', b2)
-        assert_raises(RegisterError, self.m.register, 'foo', 's1', 's2', 's3')
+        pytest.raises(RegisterError, self.m.register, 'foo', b2)
+        pytest.raises(RegisterError, self.m.register, 'foo', 's1', 's2', 's3')
 
     def test_register_anon_bundle(self):
         """Self registering an anonymous bundle.
@@ -158,8 +156,8 @@ class TestEnvApi(object):
         # An environment can be constructed without given url or directory.
         env = Environment()
         # But then accessing them will fail, and with it most operations.
-        assert_raises(EnvironmentError, getattr, env, 'url')
-        assert_raises(EnvironmentError, getattr, env, 'directory')
+        pytest.raises(EnvironmentError, getattr, env, 'url')
+        pytest.raises(EnvironmentError, getattr, env, 'directory')
 
         # Test constructing the environment with values for url and directory
         env = Environment('foo', 'bar')
@@ -185,7 +183,7 @@ class TestEnvConfig(object):
     """Custom config values through get_config/set_config.
     """
 
-    def setup(self):
+    def setup_method(self):
         self.m = Environment(None, None)
 
     def test_initial_values_override_defaults(self):
@@ -215,7 +213,7 @@ class TestSpecialProperties(object):
     as a string, and would receive object instances when accessing the property.
     """
 
-    def setup(self):
+    def setup_method(self):
         self.m = Environment('.', None)  # we won't create any files
 
     def test_versioner(self):
@@ -223,7 +221,7 @@ class TestSpecialProperties(object):
 
         # Standard string values
         self.m.versions = 'timestamp'
-        assert isinstance(self.m.config['versions'], six.string_types)
+        assert isinstance(self.m.config['versions'], str)
         assert isinstance(self.m.versions, Version)
         assert self.m.versions == 'timestamp'   # __eq__
         assert self.m.versions != 'hash'
@@ -242,7 +240,7 @@ class TestSpecialProperties(object):
 
         # Invalid value
         self.m.versions = 'invalid-value'
-        assert_raises(ValueError, getattr, self.m, 'versions')
+        pytest.raises(ValueError, getattr, self.m, 'versions')
 
     def test_cache(self):
         from webassets.cache import BaseCache, FilesystemCache
